summaryrefslogtreecommitdiff
path: root/content
diff options
context:
space:
mode:
Diffstat (limited to 'content')
-rw-r--r--content/llcache.c5
1 files changed, 4 insertions, 1 deletions
diff --git a/content/llcache.c b/content/llcache.c
index 54848cfaf..e79411279 100644
--- a/content/llcache.c
+++ b/content/llcache.c
@@ -1792,7 +1792,7 @@ llcache_object_retrieve(nsurl *url,
/* POST requests are never cached */
uncachable = true;
} else {
/* only http(s), resource, and file schemes are cached */
lwc_string *scheme;
bool match;
@@ -1806,6 +1806,9 @@ llcache_object_retrieve(nsurl *url,
lwc_string_isequal(scheme, corestring_lwc_https,
&match) == lwc_error_ok &&
(match == false) &&
+ lwc_string_isequal(scheme, corestring_lwc_data,
+ &match) == lwc_error_ok &&
+ (match == false) &&
lwc_string_isequal(scheme, corestring_lwc_resource,
&match) == lwc_error_ok &&
(match == false) &&
@@ -1792,7 +1792,7 @@ llcache_object_retrieve(nsurl *url,
uncachable = true;
} else {
- /* only http(s), resource, and file schemes are cached */
+ /* only http(s), data, resource, and file schemes are cached */
lwc_string *scheme;
bool match;